@@ -1,7 +1,7 @@
 package Log::ger;
 
 our $DATE = '2017-06-21'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 #IFUNBUILT
 # # use strict;
@@ -253,7 +253,6 @@ sub import {
 
     my $caller = caller(0);
     $args{category} = $caller if !defined($args{category});
-    $args{category} = join(".", split /::|\./, lc $args{category}); # normalize
     $Setup_Args{$caller} = \%args;
     setup_package($caller, \%args);
 }
@@ -273,7 +272,7 @@ Log::ger - A lightweight, flexible logging framework
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -324,7 +323,7 @@ See L<Log::ger::OptAway>.
 
 =item * Interoperability with other logging frameworks;
 
-See L<Log::ger::LogAny> to interop with L<Log::Any>.
+See L<Log::ger::Output::LogAny> to interop with L<Log::Any>.
 
 =back
 
