@@ -1,13 +1,16 @@
 package Log::ger::Output::String;
 
 our $DATE = '2017-06-21'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Log::ger::Util;
 
 sub import {
     my ($package, %import_args) = @_;
 
+    my $append_newline = $import_args{append_newline};
+    $append_newline = 1 unless defined $append_newline;
+
     my $plugin = sub {
         my %args = @_;
         my $level = $args{level};
@@ -17,7 +20,8 @@ sub import {
                 $msg = $formatter->($msg);
             }
             ${ $import_args{string} } .= $msg;
-            ${ $import_args{string} } .= "\n" unless $msg =~ /\R\z/;
+            ${ $import_args{string} } .= "\n"
+                unless !$append_newline || $msg =~ /\R\z/;
         };
         [$code];
     };
@@ -41,12 +45,15 @@ Log::ger::Output::String - Set output to a string
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
  use var '$str';
- use Log::ger::Output 'String' => ( string => \$str );
+ use Log::ger::Output 'String' => (
+     string => \$str,
+     # append_newline => 0, # default is true, to mimic Log::ger::Output::Screen
+ );
  use Log::ger;
 
  log_warn "blah ...";
